==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/aa-ER/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		=> 'crwdns12562:0crwdne12562:0',
    'does_not_exist' 	=> 'crwdns740:0crwdne740:0',
    'does_not_exist_var'=> 'crwdns12188:0crwdne12188:0',
    'no_tag' 	        => 'crwdns12190:0crwdne12190:0',
    'does_not_exist_or_not_requestable' => 'crwdns6581:0crwdne6581:0',
    'assoc_users'	 	=> 'crwdns741:0crwdne741:0',
    'warning_audit_date_mismatch' 	=> 'crwdns12192:0crwdne12192:0',

    'create' => [
        'error'   		=> 'crwdns742:0crwdne742:0',
        'success' 		=> 'crwdns743:0crwdne743:0',
        'success_linked' => 'crwdns11882:0crwdne11882:0',
    ],

    'update' => [
        'error'   			=> 'crwdns744:0crwdne744:0',
        'success' 			=> 'crwdns745:0crwdne745:0',
        'encrypted_warning' => 'crwdns12168:0crwdne12168:0',
        'nothing_updated'	=>  'crwdns1186:0crwdne1186:0',
        'no_assets_selected'  =>  'crwdns6810:0crwdne6810:0',
        'assets_do_not_exist_or_are_invalid' => 'crwdns12132:0crwdne12132:0',
    ],

    'restore' => [
        'error'   		=> 'crwdns1174:0crwdne1174:0',
        'success' 		=> 'crwdns1175:0crwdne1175:0',
        'bulk_success' 		=> 'crwdns11497:0crwdne11497:0',
        'nothing_updated'   => 'crwdns11499:0crwdne11499:0', 
    ],

    'audit' => [
        'error'   		=> 'crwdns12194:0crwdne12194:0',
        'success' 		=> 'crwdns1907:0crwdne1907:0',
    ],


    'deletefile' => [
        'error'   => 'crwdns1187:0crwdne1187:0',
        'success' => 'crwdns1188:0crwdne1188:0',
    ],

    'upload' => [
        'error'   => 'crwdns1189:0crwdne1189:0',
        'success' => 'crwdns1190:0crwdne1190:0',
        'nofiles' => 'crwdns1401:0crwdne1401:0',
        'invalidfiles' => 'crwdns1192:0crwdne1192:0',
    ],

    'import' => [
        'import_button'         => 'crwdns12564:0crwdne12564:0',
        'error'                 => 'crwdns1688:0crwdne1688:0',
        'errorDetail'           => 'crwdns1689:0crwdne1689:0',
        'success'               => 'crwdns1690:0crwdne1690:0',
        'file_delete_success'   => 'crwdns1698:0crwdne1698:0',
        'file_delete_error'      => 'crwdns1699:0crwdne1699:0',
        'file_missing' => 'crwdns11835:0crwdne11835:0',
        'header_row_has_malformed_characters' => 'crwdns11229:0crwdne11229:0',
        'content_row_has_malformed_characters' => 'crwdns11231:0crwdne11231:0',
    ],


    'delete' => [
        'confirm'   	=> 'crwdns746:0crwdne746:0',
        'error'   		=> 'crwdns747:0crwdne747:0',
        'nothing_updated'   => 'crwdns1876:0crwdne1876:0',
        'success' 		=> 'crwdns748:0crwdne748:0',
    ],

    'checkout' => [
        'error'   		=> 'crwdns749:0crwdne749:0',
        'success' 		=> 'crwdns750:0crwdne750:0',
        'user_does_not_exist' => 'crwdns751:0crwdne751:0',
        'not_available' => 'crwdns1691:0crwdne1691:0',
        'no_assets_selected' => 'crwdns1965:0crwdne1965:0',
    ],

    'checkin' => [
        'error'   		=> 'crwdns752:0crwdne752:0',
        'success' 		=> 'crwdns753:0crwdne753:0',
        'user_does_not_exist' => 'crwdns754:0crwdne754:0',
        'already_checked_in'  => 'crwdns1603:0crwdne1603:0',

    ],

    'requests' => [
        'error'   		=> 'crwdns1484:0crwdne1484:0',
        'success' 		=> 'crwdns1485:0crwdne1485:0',
        'canceled'      => 'crwdns1700:0crwdne1700:0',
    ],

];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/aa-ER/admin/hardware/message.php <==
<?php

return [

    'undeployable' 		 => 'crwdns12562:0crwdne12562:0',
    'does_not_exist' 	 => 'crwdns740:0crwdne740:0',
    'does_not_exist_var' => 'crwdns12188:0crwdne12188:0',
    'no_tag' 	         => 'crwdns12190:0crwdne12190:0',
    'does_not_exist_or_not_requestable' => 'crwdns6581:0crwdne6581:0',
    'assoc_users'	 	 => 'crwdns741:0crwdne741:0',
    'warning_audit_date_mismatch' 	=> 'crwdns12192:0crwdne12192:0',
    'labels_generated'   => 'crwdns12786:0crwdne12786:0',
    'error_generating_labels' => 'crwdns12788:0crwdne12788:0',
    'no_assets_selected' => 'crwdns12790:0crwdne12790:0',

    'create' => [
        'error'   		=> 'crwdns742:0crwdne742:0',
        'success' 		=> 'crwdns743:0crwdne743:0',
        'success_linked' => 'crwdns11882:0crwdne11882:0',
        'multi_success_linked' => 'crwdns12776:0crwdne12776:0',
        'partial_failure' => 'crwdns12778:0crwdne12778:0',
    ],

    'update' => [
        'error'   			=> 'crwdns744:0crwdne744:0',
        'success' 			=> 'crwdns745:0crwdne745:0',
        'encrypted_warning' => 'crwdns12168:0crwdne12168:0',
        'nothing_updated'	=>  'crwdns1186:0crwdne1186:0',
        'no_assets_selected'  =>  'crwdns6810:0crwdne6810:0',
        'assets_do_not_exist_or_are_invalid' => 'crwdns12132:0crwdne12132:0',
    ],

    'restore' => [
        'error'   		=> 'crwdns1174:0crwdne1174:0',
        'success' 		=> 'crwdns1175:0crwdne1175:0',
        'bulk_success' 		=> 'crwdns11497:0crwdne11497:0',
        'nothing_updated'   => 'crwdns11499:0crwdne11499:0', 
    ],

    'audit' => [
        'error'   		=> 'crwdns12194:0crwdne12194:0',
        'success' 		=> 'crwdns1907:0crwdne1907:0',
    ],


    'deletefile' => [
        'error'   => 'crwdns1187:0crwdne1187:0',
        'success' => 'crwdns1188:0crwdne1188:0',
    ],

    'upload' => [
        'error'   => 'crwdns1189:0crwdne1189:0',
        'success' => 'crwdns1190:0crwdne1190:0',
        'nofiles' => 'crwdns1401:0crwdne1401:0',
        'invalidfiles' => 'crwdns1192:0crwdne1192:0',
    ],

    'import' => [
        'import_button'         => 'crwdns12564:0crwdne12564:0',
        'error'                 => 'crwdns1688:0crwdne1688:0',
        'errorDetail'           => 'crwdns1689:0crwdne1689:0',
        'success'               => 'crwdns1690:0crwdne1690:0',
        'file_delete_success'   => 'crwdns1698:0crwdne1698:0',
        'file_delete_error'      => 'crwdns1699:0crwdne1699:0',
        'file_missing' => 'crwdns11835:0crwdne11835:0',
        'file_already_deleted' => 'crwdns12694:0crwdne12694:0',
        'header_row_has_malformed_characters' => 'crwdns11229:0crwdne11229:0',
        'content_row_has_malformed_characters' => 'crwdns11231:0crwdne11231:0',
    ],


    'delete' => [
        'confirm'   	=> 'crwdns746:0crwdne746:0',
        'error'   		=> 'crwdns747:0crwdne747:0',
        'nothing_updated'   => 'crwdns1876:0crwdne1876:0',
        'success' 		=> 'crwdns748:0crwdne748:0',
    ],

    'checkout' => [
        'error'   		=> 'crwdns749:0crwdne749:0',
        'success' 		=> 'crwdns750:0crwdne750:0',
        'user_does_not_exist' => 'crwdns751:0crwdne751:0',
        'not_available' => 'crwdns1691:0crwdne1691:0',
        'no_assets_selected' => 'crwdns1965:0crwdne1965:0',
    ],

    'multi-checkout' => [
        'error'   => 'crwdns12768:0crwdne12768:0',
        'success' => 'crwdns12770:0crwdne12770:0',
    ],

    'checkin' => [
        'error'   		=> 'crwdns752:0crwdne752:0',
        'success' 		=> 'crwdns753:0crwdne753:0',
        'user_does_not_exist' => 'crwdns754:0crwdne754:0',
        'already_checked_in'  => 'crwdns1603:0crwdne1603:0',

    ],

    'requests' => [
        'error'   		=> 'crwdns1484:0crwdne1484:0',
        'success' 		=> 'crwdns1485:0crwdne1485:0',
        'canceled'      => 'crwdns1700:0crwdne1700:0',
    ],

];
